@@ -106,7 +106,7 @@ extern struct _StatsOptions *last_stats_options;
     LL_CONTEXT_INNER_SRC = 16,
     LL_CONTEXT_CLIENT_PROTO = 17,
     LL_CONTEXT_SERVER_PROTO = 18,
-    LL_CONTEXT_SELECTOR = 19,
+    LL_CONTEXT_OPTIONS = 19,
     KW_SOURCE = 10000,
     KW_FILTER = 10001,
     KW_PARSER = 10002,
@@ -133,6 +133,7 @@ extern struct _StatsOptions *last_stats_options;
     KW_MARK_MODE = 10081,
     KW_ENCODING = 10082,
     KW_TYPE = 10083,
+    KW_STATS_MAX_DYNAMIC = 10084,
     KW_CHAIN_HOSTNAMES = 10090,
     KW_NORMALIZE_HOSTNAMES = 10091,
     KW_KEEP_HOSTNAME = 10092,
@@ -163,6 +164,7 @@ extern struct _StatsOptions *last_stats_options;
     KW_THREADED = 10171,
     KW_PASS_UNIX_CREDENTIALS = 10231,
     KW_PERSIST_NAME = 10302,
+    KW_READ_OLD_RECORDS = 10304,
     KW_FLAGS = 10190,
     KW_PAD_SIZE = 10200,
     KW_TIME_ZONE = 10201,
@@ -244,7 +246,7 @@ extern struct _StatsOptions *last_stats_options;
 #define LL_CONTEXT_INNER_SRC 16
 #define LL_CONTEXT_CLIENT_PROTO 17
 #define LL_CONTEXT_SERVER_PROTO 18
-#define LL_CONTEXT_SELECTOR 19
+#define LL_CONTEXT_OPTIONS 19
 #define KW_SOURCE 10000
 #define KW_FILTER 10001
 #define KW_PARSER 10002
@@ -271,6 +273,7 @@ extern struct _StatsOptions *last_stats_options;
 #define KW_MARK_MODE 10081
 #define KW_ENCODING 10082
 #define KW_TYPE 10083
+#define KW_STATS_MAX_DYNAMIC 10084
 #define KW_CHAIN_HOSTNAMES 10090
 #define KW_NORMALIZE_HOSTNAMES 10091
 #define KW_KEEP_HOSTNAME 10092
@@ -301,6 +304,7 @@ extern struct _StatsOptions *last_stats_options;
 #define KW_THREADED 10171
 #define KW_PASS_UNIX_CREDENTIALS 10231
 #define KW_PERSIST_NAME 10302
+#define KW_READ_OLD_RECORDS 10304
 #define KW_FLAGS 10190
 #define KW_PAD_SIZE 10200
 #define KW_TIME_ZONE 10201
